@@ -1,5 +1,8 @@
+from .register_util import *
 from .twitch_api_util import *
 from .connection_util import *
 from .message_util import *
 from .task_util import *
 from .misc_util import *
+from .command_util import *
+from .dict_util import *
